@@ -26,8 +26,8 @@ void cramer_vonMises(int *n, int *p, double *U, double *Ctheta,
 void cramer_vonMises_grid(int *p, double *U, int *n, double *V, int *m,
 			  double *Ctheta, double *stat);
 
-void multiplier(int *p, double *u0, int *m, double *u, int *n,
-		double *influ, int *N, double *s0);
+void multiplier(int *p, double *u0, int *m, double *u, int *n, double *b,
+		double *influ, double *denom, int *N, double *s0, int *verbose);
 
 void cramer_vonMises_Pickands(int n, int m, double *S,
 			      double *T, double *Atheta,
